@@ -148,13 +148,14 @@ NNS.boost <- function(IVs.train,
       epochs <- NULL
     }
     old.threshold <- 1
-    test.features <- list()
-    results <- numeric()
 
     if(is.null(learner.trials)){learner.trials <- length(y)}
 
     learner.trials <- min(sum(choose(n, 1:n)), learner.trials)
 
+    results <- numeric(learner.trials)
+    test.features <- list(learner.trials)
+
     for(i in 1:learner.trials){
       set.seed(123 + i)
       new.index <- sample(length(y), as.integer(CV.size*length(y)), replace = FALSE)
@@ -392,7 +393,7 @@ NNS.boost <- function(IVs.train,
   if(!is.null(cl)){
     clusterExport(cl,c("x","y"))
     if(status){
-      message("Parallel process running, status unavailable...","\r",appendLF=FALSE)
+      message("Parallel process running, status unavailable...","\r","\n",appendLF=FALSE)
     }
 
     estimates <- foreach(i = 1:dim(kf)[1], .packages = c("NNS","data.table","dtw"))%dopar%{
